<?php

namespace Drupal\simple_activecampaign;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Logger\LoggerChannelInterface;
use TestMonitor\ActiveCampaign\ActiveCampaign;
use TestMonitor\ActiveCampaign\Resources\Contact;

/**
 * ActiveCampaign API service class.
 */
final class ActiveCampaignApi implements ActiveCampaignApiInterface {

  /**
   * Logger channel.
   *
   * @var \Drupal\Core\Logger\LoggerChannelInterface
   */
  protected LoggerChannelInterface $logger;

  /**
   * ActiveCampaign API object.
   *
   * @var \TestMonitor\ActiveCampaign\ActiveCampaign
   */
  protected ActiveCampaign $api;

  /**
   * Constructs an ActiveCampaignApi object.
   */
  public function __construct(
    LoggerChannelInterface $logger,
    ConfigFactoryInterface $configFactory,
  ) {
    $this->logger = $logger;

    $config = $configFactory->get('simple_activecampaign.api_settings');
    $this->api = new ActiveCampaign(
      $config->get('api_url'),
      $config->get('api_key')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getContactLists() {
    try {
      return $this->api->lists();
    }
    catch (\Exception $e) {
      $this->logger->error('Unable to fetch contact lists via ActiveCampaign API: @message', [
        '@message' => $e->getMessage(),
      ]);
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function updateOrCreateContact($email, $firstName = '', $lastName = '', $phone = '') {
    try {
      return $this->api->updateOrCreateContact($email, $firstName, $lastName, $phone);
    }
    catch (\Exception $e) {
      $this->logger->error('Unable to create or update a contact via ActiveCampaign API: @message', [
        '@message' => $e->getMessage(),
      ]);
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function addContactToContactList(Contact $contact, $contact_list) {
    try {
      $contact->subscribe($contact_list);

      return TRUE;
    }
    catch (\Exception $e) {
      $this->logger->error('Unable to add contact to the contact list via ActiveCampaign API: @message', [
        '@message' => $e->getMessage(),
      ]);
    }

    return FALSE;
  }

}
